about summary refs log tree commit diff
path: root/pkgs/os-specific/gnu
diff options
context:
space:
mode:
authorEelco Dolstra <eelco.dolstra@logicblox.com>2012-12-28 19:08:19 +0100
committerEelco Dolstra <eelco.dolstra@logicblox.com>2012-12-28 19:08:19 +0100
commit5be0a9acd7b9abe4bff3202a7ac7defc17a37877 (patch)
tree25491a83f604f1ace6a1170505955df5817495c2 /pkgs/os-specific/gnu
parentf4ed8a3b911628335a53b3b5ddb48e9ec8d8bdcf (diff)
Rename hostDrv -> crossDrv, buildDrv -> nativeDrv
This is for consistency with terminology in stdenv (and the terms
"hostDrv" and "buildDrv" are not very intuitive, even if they're
consistent with GNU terminology).
Diffstat (limited to 'pkgs/os-specific/gnu')
-rw-r--r--pkgs/os-specific/gnu/default.nix4
-rw-r--r--pkgs/os-specific/gnu/mig/default.nix2
2 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/os-specific/gnu/mig/default.nix b/pkgs/os-specific/gnu/mig/default.nix
index f7b798a762406..7db159837fed0 100644
--- a/pkgs/os-specific/gnu/mig/default.nix
+++ b/pkgs/os-specific/gnu/mig/default.nix
@@ -25,7 +25,7 @@ stdenv.mkDerivation {
     postInstall =
       # Fix the shebang to point to the cross-built shell.
       '' sed -i "$out/bin/mig" \
-             -e 's|^#!/.*|#!${bash.hostDrv}/bin/sh|g'
+             -e 's|^#!/.*|#!${bash.crossDrv}/bin/sh|g'
       '';
   };
diff --git a/pkgs/os-specific/gnu/default.nix b/pkgs/os-specific/gnu/default.nix
index 0a42b83a46f2e..ee1ba558a07ae 100644
--- a/pkgs/os-specific/gnu/default.nix
+++ b/pkgs/os-specific/gnu/default.nix
@@ -16,7 +16,7 @@ let
       inherit fetchgit stdenv autoconf libtool texinfo
         glibcCross hurdPartedCross;
       inherit (gnu) machHeaders mig;
-      libuuid = libuuid.hostDrv;
+      libuuid = libuuid.crossDrv;
       automake = automake111x;
       headersOnly = false;
       cross = assert crossSystem != null; crossSystem;
@@ -85,7 +85,7 @@ let
       stdenv = (forceSystem "i686-linux").stdenv;
     };
 
     # XXX: Use this one for its `.hostDrv'.  Using the one above from
     # `x86_64-linux' leads to building a different cross-toolchain because of
     # the `forceSystem'.
     mig_raw = callPackage ./mig {};
@@ -85,7 +85,7 @@ let
     };
 
-    # XXX: Use this one for its `.hostDrv'.  Using the one above from
+    # XXX: Use this one for its `.crossDrv'.  Using the one above from
     # `x86_64-linux' leads to building a different cross-toolchain because of
     # the `forceSystem'.